@@ -1233,8 +1233,8 @@ licence=licence)
       (overall_status, icon, drivers) = self.gather_device_data(self.devices[device])
 
       driver_status = QLabel()
-      driver_status.setAlignment(Qt.AlignTop)
-      driver_status.setAlignment(Qt.AlignHCenter)
+      driver_status.setAlignment(Qt.AlignmentFlag.AlignTop)
+      driver_status.setAlignment(Qt.AlignmentFlag.AlignHCenter)
       pixmap = QIcon.fromTheme(icon).pixmap(QSize(16, 16))
       driver_status.setPixmap(pixmap)
 
@@ -1244,10 +1244,10 @@ licence=licence)
       device_box.addLayout(device_detail,1)#1 for priority over the icon to stretch
 
       widget = QLabel("{}: {}".format(self.devices[device].get('vendor', _('Unknown')), self.devices[device].get('model', _('Unknown'))))
-      widget.setAlignment(Qt.AlignLeft)
+      widget.setAlignment(Qt.AlignmentFlag.AlignLeft)
       device_detail.addWidget(widget)
       widget = QLabel("<small>{}</small>".format(overall_status))
-      widget.setAlignment(Qt.AlignLeft)
+      widget.setAlignment(Qt.AlignmentFlag.AlignLeft)
       #widget.set_use_markup(True)
       device_detail.addWidget(widget)
       self.dynamic_device_status[device] = (driver_status, widget)
